==> haskell-http2-2.0.3-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http2
version: 2.0.3
id: http2-2.0.3-E5GzuvFn6vFKUn2UL6IaoZ
key: http2-2.0.3-E5GzuvFn6vFKUn2UL6IaoZ
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
homepage: https://github.com/kazu-yamamoto/http2
synopsis: HTTP/2 library
description:
    HTTP/2 library including frames, priority queues, HPACK and server.
category: Network
abi: 43c37362878470fa6d1c15d7e9c00fb4
exposed: True
exposed-modules:
    Network.HPACK Network.HPACK.Table Network.HPACK.Token Network.HTTP2
    Network.HTTP2.Priority Network.HTTP2.Server
hidden-modules: Imports Network.HPACK.Builder Network.HPACK.Huffman
                Network.HPACK.Huffman.Bit Network.HPACK.Huffman.ByteString
                Network.HPACK.Huffman.Decode Network.HPACK.Huffman.Encode
                Network.HPACK.Huffman.Params Network.HPACK.Huffman.Table
                Network.HPACK.Huffman.Tree Network.HPACK.HeaderBlock
                Network.HPACK.HeaderBlock.Decode Network.HPACK.HeaderBlock.Encode
                Network.HPACK.HeaderBlock.Integer Network.HPACK.Table.Dynamic
                Network.HPACK.Table.Entry Network.HPACK.Table.RevIndex
                Network.HPACK.Table.Static Network.HPACK.Types Network.HTTP2.Decode
                Network.HTTP2.Encode Network.HTTP2.Priority.PSQ
                Network.HTTP2.Priority.Queue Network.HTTP2.Server.API
                Network.HTTP2.Server.Config Network.HTTP2.Server.Context
                Network.HTTP2.Server.EncodeFrame Network.HTTP2.Server.File
                Network.HTTP2.Server.HPACK Network.HTTP2.Server.Manager
                Network.HTTP2.Server.Queue Network.HTTP2.Server.ReadN
                Network.HTTP2.Server.Receiver Network.HTTP2.Server.Run
                Network.HTTP2.Server.Sender Network.HTTP2.Server.Stream
                Network.HTTP2.Server.Types Network.HTTP2.Server.Worker
                Network.HTTP2.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/http2-2.0.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/http2-2.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http2-2.0.3
hs-libraries: HShttp2-2.0.3-E5GzuvFn6vFKUn2UL6IaoZ
depends:
    array-0.5.3.0 base-4.12.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk containers-0.6.0.1
    http-types-0.12.3-KiHBR3VW7LN81D4RBDuP1U
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    network-byte-order-0.1.1.1-Fhie5xrs0joDg9e4EXURZg
    psqueues-0.2.7.2-1kGnrYG9qz4CkLbBbUppn9 stm-2.5.0.0
    time-manager-0.0.0-5PuzkyhD5FC4wyIFC4YEWj
haddock-interfaces: /usr/share/doc/haskell-http2/html/http2.haddock
haddock-html: /usr/share/doc/haskell-http2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http2-2.0.3-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http2
version: 2.0.3
id: http2-2.0.3-31mGbg9bCxkcNOT30MQ8b
key: http2-2.0.3-31mGbg9bCxkcNOT30MQ8b
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
homepage: https://github.com/kazu-yamamoto/http2
synopsis: HTTP/2 library
description:
    HTTP/2 library including frames, priority queues, HPACK and server.
category: Network
abi: 0881c7da0a8487f4b27988b85c1e68f5
exposed: True
exposed-modules:
    Network.HPACK Network.HPACK.Table Network.HPACK.Token Network.HTTP2
    Network.HTTP2.Priority Network.HTTP2.Server
hidden-modules: Imports Network.HPACK.Builder Network.HPACK.Huffman
                Network.HPACK.Huffman.Bit Network.HPACK.Huffman.ByteString
                Network.HPACK.Huffman.Decode Network.HPACK.Huffman.Encode
                Network.HPACK.Huffman.Params Network.HPACK.Huffman.Table
                Network.HPACK.Huffman.Tree Network.HPACK.HeaderBlock
                Network.HPACK.HeaderBlock.Decode Network.HPACK.HeaderBlock.Encode
                Network.HPACK.HeaderBlock.Integer Network.HPACK.Table.Dynamic
                Network.HPACK.Table.Entry Network.HPACK.Table.RevIndex
                Network.HPACK.Table.Static Network.HPACK.Types Network.HTTP2.Decode
                Network.HTTP2.Encode Network.HTTP2.Priority.PSQ
                Network.HTTP2.Priority.Queue Network.HTTP2.Server.API
                Network.HTTP2.Server.Config Network.HTTP2.Server.Context
                Network.HTTP2.Server.EncodeFrame Network.HTTP2.Server.File
                Network.HTTP2.Server.HPACK Network.HTTP2.Server.Manager
                Network.HTTP2.Server.Queue Network.HTTP2.Server.ReadN
                Network.HTTP2.Server.Receiver Network.HTTP2.Server.Run
                Network.HTTP2.Server.Sender Network.HTTP2.Server.Stream
                Network.HTTP2.Server.Types Network.HTTP2.Server.Worker
                Network.HTTP2.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/http2-2.0.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/http2-2.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http2-2.0.3
hs-libraries: HShttp2-2.0.3-31mGbg9bCxkcNOT30MQ8b
depends:
    array-0.5.3.0 base-4.12.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk containers-0.6.0.1
    http-types-0.12.3-DXhLFpEBHd8LSYPoefsPrf
    network-2.8.0.1-L17Rv8Nouqq1qZnRto8DBo
    network-byte-order-0.1.1.1-8GtJEY3mgykChCics8nI
    psqueues-0.2.7.2-AwqkuuEovPlCyBQNQ2HZ06 stm-2.5.0.0
    time-manager-0.0.0-BUjOqWfcVf9JomOSIMmUqx
haddock-interfaces: /usr/share/doc/haskell-http2/html/http2.haddock
haddock-html: /usr/share/doc/haskell-http2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
